@@ -33,7 +33,11 @@
 #include <string.h>
 #include <errno.h>
 #include <unistd.h>
+#ifdef __linux__
 #include <termio.h>
+#else
+#include <termios.h>
+#endif /* of __linux__ */
 
 #include "term.h"
 
@@ -954,7 +958,7 @@ term_pulse_dtr (int fd)
 		}
 #else
 		{
-			struct termios tio;
+			struct termios tio, tioold;
 
 			r = tcgetattr(fd, &tio);
 			if ( r < 0 ) {
